@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-10-12'; # DATE
-our $VERSION = '1.27'; # VERSION
+our $DATE = '2015-11-27'; # DATE
+our $VERSION = '1.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -514,7 +514,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         inline_gen_args => {load_module=>['Perinci::Examples::Tiny::Args']},
                         argv           => [qw/--arg abc --format json/],
                         exit_code      => 0,
-                        stdout_like    => qr/^\[\s*200,\s*"OK",\s*"abc",\s*\{\}\s*\]/s,
+                        stdout_like    => qr/^\[\s*"?200"?,\s*"OK",\s*"abc",\s*\{.*\}\s*\]/s,
                     },
                     {
                         name           => 'common option: --json',
@@ -522,7 +522,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         inline_gen_args => {load_module=>['Perinci::Examples::Tiny::Args']},
                         argv           => [qw/--arg abc --json/],
                         exit_code      => 0,
-                        stdout_like    => qr/^\[\s*200,\s*"OK",\s*"abc",\s*\{\}\s*\]/s,
+                        stdout_like    => qr/^\[\s*"?200"?,\s*"OK",\s*"abc",\s*\{.*\}\s*\]/s,
                     },
                     {
                         name           => 'common option: --naked-res',
@@ -538,7 +538,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         inline_gen_args => {load_module=>['Perinci::Examples::Tiny::Args']},
                         argv           => [qw/--arg abc --json --no-naked-res/],
                         exit_code      => 0,
-                        stdout_like    => qr/^\[\s*200,\s*"OK",\s*"abc",\s*\{\}\s*\]/s,
+                        stdout_like    => qr/^\[\s*"?200"?,\s*"OK",\s*"abc",\s*\{.*\}\s*\]/s,
                     },
                     {
                         tags           => ['subcommand'],
@@ -563,7 +563,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         inline_gen_args => {load_module=>['Perinci::Examples::Tiny::Args']},
                         argv           => ['--arg-json', '["a","b"]', '--json'],
                         exit_code      => 0,
-                        stdout_like    => qr/^\[\s*200,\s*"OK",\s*\[\s*"a",\s*"b"\s*\],\s*\{\}\s*\]/s,
+                        stdout_like    => qr/^\[\s*"?200"?,\s*"OK",\s*\[\s*"a",\s*"b"\s*\],\s*\{.*\}\s*\]/s,
                     },
                 ],
             }, # call action
@@ -575,7 +575,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags       => ['cmdline_src'],
                         name       => 'unknown value',
                         gen_args   => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_unknown"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv       => [],
                         exit_code  => 231,
                     },
@@ -583,7 +583,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags       => ['cmdline_src'],
                         name       => 'arg type not str/array',
                         gen_args   => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_invalid_arg_type"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv       => [],
                         exit_code  => 231,
                     },
@@ -591,7 +591,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags       => ['cmdline_src', 'cmdline_src:stdin'],
                         name       => 'multiple stdin',
                         gen_args   => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_multi_stdin"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv       => [qw/a b/],
                         exit_code  => 200,
                     },
@@ -836,7 +836,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags        => ['cmdline_src', 'cmdline_src:stdin_or_files'],
                         name        => 'stdin_or_files file',
                         gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_files_array"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv        => ["$tempdir/infile1", "$tempdir/infile2"],
                         stdout_like => qr/a1=\[foo,bar\n,baz\]$/,
                     },
@@ -844,7 +844,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags        => ['cmdline_src', 'cmdline_src:stdin_or_files'],
                         name        => 'stdin_or_files file (special hint arguments passed)',
                         gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_files_str"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv        => ['--json', "$tempdir/infile1"],
                         stdout_like => [
                             qr/"-cmdline_src_a1"\s*:\s*"stdin_or_files"/sx,
@@ -855,7 +855,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags        => ['cmdline_src', 'cmdline_src:stdin_or_files'],
                         name        => 'stdin_or_files file not found',
                         gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_files_str"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv        => ["$tempdir/infile1/x"],
                         exit_code   => 200,
                     },
@@ -863,7 +863,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags        => ['cmdline_src', 'cmdline_src:stdin_or_files'],
                         name        => 'stdin_or_files stdin str',
                         gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_files_str"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv        => [],
                         stdin       => "bar\nbaz",
                         stdout_like => qr/a1=bar\nbaz$/,
@@ -873,7 +873,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         tags        => ['cmdline_src', 'cmdline_src:stdin_or_files'],
                         name        => 'stdin_or_files stdin str',
                         gen_args    => {url=>"/Perinci/Examples/CmdLineSrc/cmdline_src_stdin_or_files_array"},
-                        inline_gen_args => {load_module=>["/Perinci/Examples/CmdLineSrc"]},
+                        inline_gen_args => {load_module=>["Perinci::Examples::CmdLineSrc"]},
                         argv        => [],
                         stdin       => "bar\nbaz",
                         stdout_like => qr/a1=\[bar\n,baz\]/,
@@ -969,7 +969,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         exit_code => 200,
                     },
                     {
-                        tags        => ['streaming', 'streaming-output'],
+                        tags        => ['streaming', 'streaming-input', 'streaming-output'],
                         name        => "stream output (simple types)",
                         gen_args    => {url => '/Perinci/Examples/Stream/square_input'},
                         argv        => ["$tempdir/infile4"],
@@ -989,6 +989,7 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                                              ^\Q{"num":2}\E\n
                                              ^\Q{"num":3}\E\n
                                          /mx,
+                        inline_gen_args => {load_module=>["Perinci::Examples::Stream"]},
                     },
                 ],
             }, # streaming
@@ -1354,7 +1355,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.27 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-10-12.
+This document describes version 1.28 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-11-27.
 
 =head1 SEE ALSO
 
